@@ -453,11 +453,30 @@ module RSpec
       add_setting :threadsafe
 
       # @macro add_setting
-      # Maximum count of failed source lines to display in the failure reports.
-      # (default `10`).
+      # Maximum count of failed source lines to display in the failure reports
+      # (defaults to `10`).
       # return [Integer]
       add_setting :max_displayed_failure_line_count
 
+      # @macro full_cause_backtrace
+      # Display the full backtrace of an exceptions cause (defaults to `false`).
+      # return [Boolean]
+      add_setting :full_cause_backtrace
+
+      # @macro add_setting
+      # Format the output for pending examples. Can be set to:
+      #  - :full (default) - pending examples appear similarly to failures
+      #  - :no_backtrace - same as above, but with no backtrace
+      #  - :skip - do not show the section at all
+      # return [Symbol]
+      add_read_only_setting :pending_failure_output
+      def pending_failure_output=(mode)
+        raise ArgumentError,
+              "`pending_failure_output` can be set to :full, :no_backtrace, " \
+              "or :skip" unless [:full, :no_backtrace, :skip].include?(mode)
+        @pending_failure_output = mode
+      end
+
       # Determines which bisect runner implementation gets used to run subsets
       # of the suite during a bisection. Your choices are:
       #
@@ -557,8 +576,10 @@ module RSpec
         @derived_metadata_blocks = FilterableItemRepository::QueryOptimized.new(:any?)
         @threadsafe = true
         @max_displayed_failure_line_count = 10
+        @full_cause_backtrace = false
         @world = World::Null
         @shared_context_metadata_behavior = :trigger_inclusion
+        @pending_failure_output = :full
 
         define_built_in_hooks
       end
@@ -2120,6 +2141,13 @@ module RSpec
         suggestions = DidYouMean.new(relative_file).call
         reporter.notify_non_example_exception(ex, "An error occurred while loading #{relative_file}.#{suggestions}")
         RSpec.world.wants_to_quit = true
+      rescue SyntaxError => ex
+        relative_file = Metadata.relative_path(file)
+        reporter.notify_non_example_exception(
+          ex,
+          "While loading #{relative_file} a `raise SyntaxError` occurred, RSpec will now quit."
+        )
+        RSpec.world.rspec_is_quitting = true
       rescue Support::AllExceptionsExceptOnesWeMustNotRescue => ex
         relative_file = Metadata.relative_path(file)
         reporter.notify_non_example_exception(ex, "An error occurred while loading #{relative_file}.")
